==> dmagnetic_0.36.orig.tar.gz: dmagnetic-0.36/src/loader/maggfxloader.h <==
/*

Copyright 2023, dettus@dettus.net

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, 
   this list of conditions and the following disclaimer in the documentation 
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


*/
#ifndef	MAGGFXLOADER_H
#define	MAGGFXLOADER_H

#define	MAXFILENAMESIZE	1024
typedef	enum _eBinType
{
	BINTYPE_NONE,
	BINTYPE_MAGGFX,
	BINTYPE_MSDOS,
	BINTYPE_TWORSC,
	BINTYPE_D64,
	BINTYPE_AMSTRADCPC,
	BINTYPE_SPECTRUM,
	BINTYPE_ARCHIMEDES,
	BINTYPE_ATARIXL,
	BINTYPE_APPLEII
} eBinType;

int maggfxloader(char *magbuf,int* magsize,
	char* gfxbuf,int* gfxsize,
	int nodoc,
	eBinType binType,char* magfilename,char* gfxfilename,char* binfilename);
#endif

==> dmagnetic_0.37.orig.tar.gz: dmagnetic-0.37/src/loader/maggfxloader.h <==
/*

Copyright 2023, dettus@dettus.net

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, 
   this list of conditions and the following disclaimer in the documentation 
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


*/
#ifndef	MAGGFXLOADER_H
#define	MAGGFXLOADER_H

#define	MAXFILENAMESIZE	1024
typedef	enum _eBinType
{
	BINTYPE_NONE,
	BINTYPE_MAGGFX,
	BINTYPE_MSDOS,
	BINTYPE_TWORSC,
	BINTYPE_D64,
	BINTYPE_AMSTRADCPC,
	BINTYPE_SPECTRUM,
	BINTYPE_ARCHIMEDES,
	BINTYPE_ATARIXL,
	BINTYPE_APPLEII
} eBinType;
typedef enum _eFileType
{
	FILETYPE_UNKNOWN,
	FILETYPE_MAG,
	FILETYPE_GFX
} eFileType;

int maggfxloader(char *magbuf,int* magsize,
	char* gfxbuf,int* gfxsize,
	int nodoc,
	eBinType binType,char* magfilename,char* gfxfilename,char* binfilename);
int maggfxguesstype(char* filename,eFileType *pFileType);
#endif
